#
# Author: Rui Prior
# (C) LIACC - Universidade do Porto
#

set ns [new Simulator]
$ns set-address-format hierarchical
AddrParams set domain_num_ 3

# Initializations
#set tf [open out_sip_test.tr w]
set nf [open out_sip_test.nam w]
$ns namtrace-all $nf


# Routers
set n0 [$ns node 0.0.0]
set n1 [$ns node 1.0.0]
set n2 [$ns node 2.0.0]
set n3 [$ns node 1.1.0]
set n4 [$ns node 2.1.0]
# Proxies
set n5 [$ns node 1.0.1]
set n6 [$ns node 2.0.1]
# Terminals
set n7 [$ns node 1.1.2]
set n8 [$ns node 2.1.2]

# Set nodes' positions
$n0 set X_ 100
$n0 set Y_ 150
$n1 set X_ 60
$n1 set Y_ 110
$n2 set X_ 140
$n2 set Y_ 110
$n3 set X_ 60
$n3 set Y_ 60
$n4 set X_ 140
$n4 set Y_ 60
$n5 set X_ 10
$n5 set Y_ 110
$n6 set X_ 190
$n6 set Y_ 110
$n7 set X_ 60
$n7 set Y_ 10
$n8 set X_ 140
$n8 set Y_ 10


# Set nodes' colors
$n0 color black
$n1 color black
$n2 color black
$n3 color black
$n4 color black
$n5 color orange
$n6 color orange
$n7 color blue
$n8 color blue


# Routers
$ns duplex-link $n0 $n1 1Mb 10ms DropTail
$ns duplex-link $n0 $n2 1Mb 10ms DropTail
$ns duplex-link $n1 $n3 1Mb 10ms DropTail
$ns duplex-link $n2 $n4 1Mb 10ms DropTail
# Proxies
$ns duplex-link $n1 $n5 1Mb 10ms DropTail
$ns duplex-link $n2 $n6 1Mb 10ms DropTail
# Terminals
$ns duplex-link $n3 $n7 1Mb 10ms DropTail
$ns duplex-link $n4 $n8 1Mb 10ms DropTail


# Proxy servers
$n5 label "proxy.atlanta.com"
set serveraddrATL [$n5 node-addr]
set sipATL [new Agent/SIPProxy atlanta.com]
$ns attach-agent $n5 $sipATL
$n6 label "proxy.biloxi.com"
set serveraddrBLX [$n6 node-addr]
set sipBLX [new Agent/SIPProxy biloxi.com]
$ns attach-agent $n6 $sipBLX


# User agents
$n7 label "alice@atlanta.com"
set sipalice [new Agent/SIPUA alice atlanta.com]
$ns attach-agent $n7 $sipalice
$n8 label "bob@biloxi.com"
set sipbob [new Agent/SIPUA bob biloxi.com]
$ns attach-agent $n8 $sipbob



# Setup outbound proxies
$sipalice set-proxy $serveraddrATL
$sipbob set-proxy $serveraddrBLX


# Set Record-Route on proxies
$sipATL set recordRoute_ 1
$sipBLX set recordRoute_ 1


# Register proxies with DNS "God"
DNSGod register proxy atlanta.com $serveraddrATL
DNSGod register proxy biloxi.com $serveraddrBLX


#finish procedure
proc finish {} {
	global ns tf nf
	$ns flush-trace
	#close $tf
	close $nf
	puts "NS-simulation finished!"
	exit 0
}

# Put nodes in place again
$ns at 0.0 "$ns dump-namnodes"



# Configure one terminal for complex response, waiting between 1 and 3
# seconds after ringing to pick up the phone
$sipbob set simple_ 0
$sipbob set minAnsDel_ 1.0
$sipbob set maxAnsDel_ 3.0


# Register nodes at home
$ns at 1.0 "$ns trace-annotate \"Registering alice@atlanta.com\""
$ns at 1.0 "$sipalice register"
$ns at 1.1 "$ns trace-annotate \"Registering bob@biloxi.com\""
$ns at 1.1 "$sipbob register"

# Sessions
$ns at 5.0 "$ns trace-annotate \"alice@atlanta.com starts session to bob@biloxi.com\""
$ns at 5.0 "$sipalice invite bob biloxi.com bw 32kb 64kb"

$ns at 10.0 "$ns trace-annotate \"bob@biloxi.com ends session to alice@atlanta.com (any side may terminate the call)\""
$ns at 10.0 "$sipbob bye"


$ns at 100.0 "finish"

$ns run

